@@ -1,4 +1,4 @@
-from typing import Dict, List, Callable, Iterable
+from typing import Dict, List, Tuple, Callable, Iterable
 
 from .timer import Timer
 from .basic_test import Test
@@ -18,6 +18,12 @@ class TestSuite:
     # Data providers (available to all tests in all sets)
     providers: Dict[str, Callable[[None], Iterable]] = {}
 
+    # Cache for providers, store name-tuple of values
+    cache: Dict[str, Tuple] = {}
+
+    # Container for cached providers, stores only names!
+    cached: List[str] = []
+
     # Lists of functions which execute before and after run
     before: List[Callable] = []
     after: List[Callable] = []
@@ -144,3 +150,12 @@ class TestSuite:
     @classmethod
     def suite_duration(cls) -> float:
         return cls.timer.duration
+
+    @classmethod
+    def info(cls) -> Dict:
+        """
+        Statistics of whole test-suite
+        :return: dict of main parameters
+        """
+        return {'name': cls.name, 'groups': tuple(cls.groups.keys()), 'providers': tuple(cls.providers.keys()),
+                'tests_count': cls.tests_count(), 'duration': cls.suite_duration()}
